==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/PersistenceParser__24JavaHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$JavaHandlerCreator

// class file dependencies
// @dep_class 2ef3349917e89269 gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *);

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/PersistenceParser__24JavaHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$JavaHandlerCreator

// class file dependencies
// @dep_class eb5801c6acd7cdc8 gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24JavaHandlerCreator_H_ */
